@@ -320,12 +320,12 @@ def _bq_table_to_df(
 
     if not spark_session:
         spark_session = get_spark()
-    spark_session.conf.set("spark.sql.execution.arrow.enabled", "false")
+    spark_session.conf.set("spark.sql.execution.arrow.pyspark.enabled", "false")
     key = get_secrets(CREDENTIALS_SECRET_MOUNT_POINT, CREDENTIALS_SECRET_PATH)["config"]
     df = (
         spark_session.read.format("bigquery")
-        .option("project", "emart-datafabric")
-        .option("table", f"emart-datafabric:{dataset}.{table_name}")
+        .option("project", PROJECT_ID)
+        .option("table", f"{PROJECT_ID}:{dataset}.{table_name}")
         .option("credentials", base64.b64encode(key.encode()).decode())
     )
     if partition:
@@ -404,7 +404,7 @@ def _df_to_bq_table(
     )
     df = (
         df.write.format("bigquery")
-        .option("project", "emart-datafabric")
+        .option("project", PROJECT_ID)
         .option("credentials", base64.b64encode(key.encode()).decode())
         .option("table", table)
         .option("temporaryGcsBucket", "emart-datafabric-temp-7d")
